==> 0.0.5%2B4.tar.gz: lib/widgets/spark_label_title.dart <==
part of spark_widget;

class SparkLabelTitle extends SparkFormWidget {
  const SparkLabelTitle({
    Key? key,
    required FormGroupItem manage,
    this.suffixIcon,
    this.showSuffix = true,
    this.suffixSize,
    this.maxLines,
    this.onTap,
    this.hitText,
    this.style,
    this.hitTextStyle,
    this.padding = EdgeInsets.zero,
    this.margin,
    this.width,
    this.selectDown = false,
    this.contentPadding,
    this.alignment,
  }) : super(key: key, manage: manage);

  /// custom suffix icon
  final Widget? suffixIcon;

  /// set show suffix icon
  final bool showSuffix;

  /// set suffix icon size
  final Size? suffixSize;

  /// set text max line count
  final int? maxLines;

  /// label tap
  final void Function(
      SparkLabelTitleData data, Function(SparkLabelTitleData? data))? onTap;

  /// empty hit text
  final String? hitText;

  /// show text style
  final TextStyle? style;

  /// hit text style
  final TextStyle? hitTextStyle;

  /// set body padding
  final EdgeInsets padding;

  /// set body margin
  final EdgeInsets? margin;

  final double? width;

  /// choose suffix icon type
  final bool selectDown;

  /// set content and suffix padding
  final EdgeInsets? contentPadding;

  final Alignment? alignment;

  @override
  State<StatefulWidget> createState() => _SparkLabelTitleBase();
}

class _SparkLabelTitleBase
    extends SparkFormWidgetBase<SparkLabelTitle, SparkLabelTitleData> {
  void _clickHandle() {
    if (widget.onTap != null) {
      widget.onTap!(fieldData, (_newData) {
        if (_newData != null) {
          fieldData.title = _newData.title;
          fieldData.data = _newData.data;
          manage.update();
        }
      });
    }
  }

  @override
  initState() {
    manage.registerClickCallback(_clickHandle);
    super.initState();
  }

  Widget _buildLabelTitle(BuildContext context, SparkTheme? theme) {
    String _title = fieldData.title;
    bool isHitText = false;
    if (emptyOrNullString(_title)) {
      _title = widget.hitText ?? '';
      isHitText = true;
    }
    TextStyle? _style = !isHitText
        ? (widget.style ??
            TextStyle(
              fontSize: theme?.labelFontSize,
              color: theme?.labelColor,
            ))
        : (widget.hitTextStyle ??
            TextStyle(
              fontSize: theme?.labelFontSize,
              color: theme?.hitColor,
            ));
    return Expanded(
      flex: 1,
      child: Container(
        alignment: widget.alignment ?? Alignment.topRight,
        padding: widget.contentPadding,
        margin: widget.margin,
        width: widget.width,
        child: Text(
          _title,
          style: _style,
          maxLines: widget.maxLines,
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }

  Widget? _buildSuffix() {
    if (!widget.showSuffix) {
      return null;
    }
    Size _size = widget.suffixSize ?? const Size(12, 12);
    return widget.suffixIcon ??
        SizedBox(
          width: _size.width,
          height: _size.height,
          child: _buildDefaultSuffixIcon(_size),
        );
  }

  Widget _buildDefaultSuffixIcon(Size size) {
    return Image.asset(
      widget.selectDown
          ? 'icons/icon_arrow_down.png'
          : 'icons/icon_arrow_right_grey.png',
      width: size.width,
      height: size.height,
      scale: 1,
      package: 'spark_form',
    );
  }

  @override
  dispose() {
    // just remove
    manage.clearClickCallback();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    Widget? _suffix = _buildSuffix();
    SparkTheme? theme = SparkThemeData.of(context);
    return SparkWrapper(
      manage: manage,
      builder: (_, _value, _updater) {
        return Padding(
          padding: widget.padding,
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              _buildLabelTitle(context, theme),
              if (_suffix != null) _suffix,
            ],
          ),
        );
      },
    );
  }

  @override
  void valueChangeNotify() {
    //
  }
}

class SparkLabelTitleData extends SparkFormDataChangeImp {
  SparkLabelTitleData(this.title, dynamic data) : super(data);

  SparkLabelTitleData.from(this.title, dynamic data) : super(data);

  String title;
}

==> 0.0.6%2B4.tar.gz: lib/widgets/spark_label_title.dart <==
part of spark_widget;

class SparkLabelTitle extends SparkFormWidget {
  const SparkLabelTitle({
    Key? key,
    required FormGroupItem manage,
    this.suffixIcon,
    this.showSuffix = true,
    this.suffixSize,
    this.maxLines,
    this.onTap,
    this.hitText,
    this.style,
    this.hitTextStyle,
    this.padding = EdgeInsets.zero,
    this.margin,
    this.width,
    this.selectDown = false,
    this.contentPadding,
    this.alignment,
  }) : super(key: key, manage: manage);

  /// custom suffix icon
  final Widget? suffixIcon;

  /// set show suffix icon
  final bool showSuffix;

  /// set suffix icon size
  final Size? suffixSize;

  /// set text max line count
  final int? maxLines;

  /// label tap
  final void Function(
      SparkLabelTitleData data, Function(SparkLabelTitleData? data))? onTap;

  /// empty hit text
  final String? hitText;

  /// show text style
  final TextStyle? style;

  /// hit text style
  final TextStyle? hitTextStyle;

  /// set body padding
  final EdgeInsets padding;

  /// set body margin
  final EdgeInsets? margin;

  final double? width;

  /// choose suffix icon type
  final bool selectDown;

  /// set content and suffix padding
  final EdgeInsets? contentPadding;

  final Alignment? alignment;

  @override
  State<StatefulWidget> createState() => _SparkLabelTitleBase();
}

class _SparkLabelTitleBase
    extends SparkFormWidgetBase<SparkLabelTitle, SparkLabelTitleData> {
  void _clickHandle() {
    if (widget.onTap != null) {
      widget.onTap!(fieldData, (_newData) {
        if (_newData != null) {
          fieldData.title = _newData.title;
          fieldData.data = _newData.data;
          manage.update();
        }
      });
    }
  }

  @override
  initState() {
    manage.registerClickCallback(_clickHandle);
    super.initState();
  }

  Widget _buildLabelTitle(BuildContext context, SparkTheme? theme) {
    String _title = fieldData.title;
    bool isHitText = false;
    if (emptyOrNullString(_title)) {
      _title = widget.hitText ?? '';
      isHitText = true;
    }
    TextStyle? _style = !isHitText
        ? (widget.style ??
            TextStyle(
              fontSize: theme?.labelTitleFontSize,
              color: theme?.labelTitleColor,
            ))
        : (widget.hitTextStyle ??
            TextStyle(
              fontSize: theme?.labelTitleFontSize,
              color: theme?.hitColor,
            ));
    return Expanded(
      flex: 1,
      child: Container(
        alignment: widget.alignment ?? Alignment.topRight,
        padding: widget.contentPadding,
        margin: widget.margin,
        width: widget.width,
        child: Text(
          _title,
          style: _style,
          maxLines: widget.maxLines,
          overflow: TextOverflow.ellipsis,
        ),
      ),
    );
  }

  Widget? _buildSuffix() {
    if (!widget.showSuffix) {
      return null;
    }
    Size _size = widget.suffixSize ?? const Size(12, 12);
    return widget.suffixIcon ??
        SizedBox(
          width: _size.width,
          height: _size.height,
          child: _buildDefaultSuffixIcon(_size),
        );
  }

  Widget _buildDefaultSuffixIcon(Size size) {
    return Image.asset(
      widget.selectDown
          ? 'icons/icon_arrow_down.png'
          : 'icons/icon_arrow_right_grey.png',
      width: size.width,
      height: size.height,
      scale: 1,
      package: 'spark_form',
    );
  }

  @override
  dispose() {
    // just remove
    manage.clearClickCallback();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    Widget? _suffix = _buildSuffix();
    SparkTheme? theme = SparkThemeData.of(context);
    return SparkWrapper(
      manage: manage,
      builder: (_, _value, _updater) {
        return Padding(
          padding: widget.padding,
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              _buildLabelTitle(context, theme),
              if (_suffix != null) _suffix,
            ],
          ),
        );
      },
    );
  }

  @override
  void valueChangeNotify() {
    //
  }
}

class SparkLabelTitleData extends SparkFormDataChangeImp {
  SparkLabelTitleData(this.title, dynamic data) : super(data);

  SparkLabelTitleData.from(this.title, dynamic data) : super(data);

  String title;
}
